Struct aws_sdk_secretsmanager::output::CreateSecretOutput[][src]

#[non_exhaustive]
pub struct CreateSecretOutput { pub arn: Option<String>, pub name: Option<String>, pub version_id: Option<String>, pub replication_status: Option<Vec<ReplicationStatusType>>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
arn: Option<String>

The Amazon Resource Name (ARN) of the secret that you just created.

Secrets Manager automatically adds several random characters to the name at the end of the ARN when you initially create a secret. This affects only the ARN and not the actual friendly name. This ensures that if you create a new secret with the same name as an old secret that you previously deleted, then users with access to the old secret don't automatically get access to the new secret because the ARNs are different.

name: Option<String>

The friendly name of the secret that you just created.

version_id: Option<String>

The unique identifier associated with the version of the secret you just created.

replication_status: Option<Vec<ReplicationStatusType>>

Describes a list of replication status objects as InProgress, Failed or InSync.

Implementations

The Amazon Resource Name (ARN) of the secret that you just created.

Secrets Manager automatically adds several random characters to the name at the end of the ARN when you initially create a secret. This affects only the ARN and not the actual friendly name. This ensures that if you create a new secret with the same name as an old secret that you previously deleted, then users with access to the old secret don't automatically get access to the new secret because the ARNs are different.

The friendly name of the secret that you just created.

The unique identifier associated with the version of the secret you just created.

Describes a list of replication status objects as InProgress, Failed or InSync.

Creates a new builder-style object to manufacture CreateSecretOutput